@@ -1185,31 +1185,45 @@ accessx_status_applet_resize (GtkWidget *widget, int size, gpointer user_data)
 }
 
 static void
-accessx_status_applet_background (PanelApplet *a, PanelAppletBackgroundType type,
-				  GdkColor *color, GdkPixmap *pixmap, gpointer user_data)
+accessx_status_applet_background (PanelApplet *a,
+				  PanelAppletBackgroundType type,
+				  GdkColor *color,
+				  GdkPixmap *pixmap,
+				  gpointer user_data)
 {
 	AccessxStatusApplet *sapplet = user_data;
-	GtkRcStyle *rc_style = gtk_rc_style_new ();
 
-	switch (type) {
-	case PANEL_PIXMAP_BACKGROUND:
-		gtk_widget_modify_style (GTK_WIDGET (sapplet->applet), rc_style);
-		break;
+        GtkRcStyle *rc_style;
+        GtkStyle *style;
 
-	case PANEL_COLOR_BACKGROUND:
-		gtk_widget_modify_bg (GTK_WIDGET (sapplet->applet), GTK_STATE_NORMAL, color);
-		break;
+        /* reset style */
+        gtk_widget_set_style (GTK_WIDGET (sapplet->applet), NULL);
+        rc_style = gtk_rc_style_new ();
+        gtk_widget_modify_style (GTK_WIDGET (sapplet->applet), rc_style);
+        g_object_unref (rc_style);
 
-	case PANEL_NO_BACKGROUND:
-		gtk_widget_modify_style (GTK_WIDGET (sapplet->applet), rc_style);
-		break;
+        switch (type) {
+                case PANEL_COLOR_BACKGROUND:
+                        gtk_widget_modify_bg (GTK_WIDGET (sapplet->applet),
+                                        GTK_STATE_NORMAL, color);
+                        break;
 
-	default:
-		gtk_widget_modify_style (GTK_WIDGET (sapplet->applet), rc_style);
-		break;
-	}
+                case PANEL_PIXMAP_BACKGROUND:
+                        style = gtk_style_copy (
+                                        GTK_WIDGET (sapplet->applet)->style);
+                        if (style->bg_pixmap[GTK_STATE_NORMAL])
+                                g_object_unref
+                                        (style->bg_pixmap[GTK_STATE_NORMAL]);
+                        style->bg_pixmap[GTK_STATE_NORMAL] = g_object_ref
+                                (pixmap);
+                        gtk_widget_set_style (GTK_WIDGET (sapplet->applet),
+                                        style);
+                        break;
 
-	gtk_rc_style_unref (rc_style);
+                case PANEL_NO_BACKGROUND:
+                default:
+                        break;
+        }
 }
 
 static gboolean
