@@ -1,4 +1,4 @@
-/* $Id: gweather-about.c,v 1.19 2005/01/09 17:34:36 davyd Exp $ */
+/* $Id: gweather-about.c,v 1.20 2005/01/18 18:09:49 bdejean Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -26,9 +26,6 @@
 
 void gweather_about_run (GWeatherApplet *gw_applet)
 {
-    GtkIconInfo *icon_info;
-    GdkPixbuf   *pixbuf = NULL;
-    GError	*error = NULL;
     
     static const gchar *authors[] = {
 	"Kevin Vandersloot <kfv101@psu.edu>",
